==> nextcloud-22.2.4.tgz: nextcloud/apps/settings/l10n/af.js <==
OC.L10N.register(
    "settings",
    {
    "Saved" : "Bewaar",
    "Email sent" : "E-pos gestuur",
    "Very weak password" : "Baie swak wagwoord",
    "Weak password" : "Swak wagwoord",
    "So-so password" : "Gemiddelde wagwoord",
    "Good password" : "Goeie wagwoord",
    "Strong password" : "Sterk wagwoord",
    "Groups" : "Groepe",
    "Group list is empty" : "Groeplys is leeg",
    "Unable to retrieve the group list" : "Kan nie die groeplys ophaal nie",
    "{actor} changed your password" : "{actor} het u wagwoord verander",
    "You changed your password" : "U het u wagwoord verander",
    "Your password was reset by an administrator" : "U wagwoord is deur ’n administrateur herstel",
    "{actor} changed your email address" : "{actor} het u e-posadres verander",
    "You changed your email address" : "U het u e-posadres verander",
    "Your email address was changed by an administrator" : "U e-posadres is deur ’n administrateur verander",
    "Security" : "Sekuriteit",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "U <strong>wagwoord</strong> of <strong>e-pos</strong> is gewysig",
    "Wrong password" : "Verkeerde wagwoord",
    "No user supplied" : "Geen gebruiker verskaf nie",
    "Well done, %s!" : "Welgedaan %s!",
    "Invalid mail address" : "Ongeldige posadres",
    "Settings saved" : "Instellings gestoor",
    "Go to %s" : "Gaan na %s",
    "Apps" : "Toeps",
    "Settings" : "Instellings",
    "Personal" : "Persoonlik",
    "Personal info" : "Persoonlike inligting",
    "Create" : "Skep",
    "Delete" : "Skrap",
    "Unlimited" : "Onbeperkte",
    "None" : "Geen",
    "Save changes" : "Bewaar veranderinge",
    "All" : "Alle",
    "Update to {version}" : "Werk by na {version}",
    "Remove" : "Verwyder",
    "Disable" : "Deaktiveer",
    "View in store" : "Bekyk in winkel",
    "Visit website" : "Besoek webwerf",
    "User documentation" : "Gebruikerdokumentasie",
    "Admin documentation" : "Admindokumentasie",
    "Developer documentation" : "Ontwikkelaardokumentasie",
    "Rename" : "Hernoem",
    "Device" : "Toestel",
    "App name" : "Toepnaam",
    "Create new app password" : "Skep nuwe toepwagwoord",
    "Username" : "Gebruikersnaam",
    "Password" : "Wagwoord",
    "Done" : "Gereed",
    "Copied!" : "Gekopieer!",
    "Copy" : "Kopieer",
    "Your email address" : "U e-posadres",
    "No email address set" : "Geen e-posadres ingestel",
    "Language" : "Taal",
    "Help translate" : "Help met vertaling",
    "Add" : "Voeg by",
    "Cancel" : "Kanselleer",
    "Display name" : "Vertoonnaam",
    "Email" : "E-pos",
    "Group admin for" : "Groepadmin vir",
    "Quota" : "Kwota",
    "Last login" : "Laaste aantekening",
    "Default quota" : "Verstekkwota",
    "Unnamed device" : "Onbenoemde toestel",
    "Your apps" : "U toeps",
    "Disabled apps" : "Gedeaktiveerde toeps",
    "Updates" : "Bywerkings",
    "App bundles" : "Toepbundels",
    "Details" : "Besonderhede",
    "Changelog" : "Veranderingslog",
    "Send email to new user" : "Stuur e-pos aan nuwe gebruiker",
    "Address" : "Adres",
    "Full name" : "Volle naam",
    "Phone number" : "Foonnommer",
    "Twitter" : "Twitter",
    "Website" : "Webwerf",
    "Enable" : "Aktiveer",
    "Never" : "Nooit",
    "Administrator documentation" : "Administrateurdokumentasie",
    "Documentation" : "Dokumentasie",
    "Forum" : "Forum",
    "Login" : "Teken aan",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "Open dokumentasie",
    "Encryption" : "Enkripsie",
    "Authentication required" : "Verifikasie word vereis",
    "Server address" : "Bedieneradres",
    "Port" : "Poort",
    "SMTP Password" : "SMTP-wagwoord",
    "Save" : "Stoor",
    "Version" : "Weergawe",
    "Like our Facebook page" : "Hou van ons Facebook-blad",
    "Follow us on Twitter" : "Volg ons op Twitter",
    "Check out our blog" : "Besoek ons woernaal",
    "Subscribe to our newsletter" : "Teken in op ons nuusbrief",
    "Profile picture" : "Profielprent",
    "Upload new" : "Laai nuwe op",
    "Select from Files" : "Kies uit Lêers",
    "Remove image" : "Verwyder beeld",
    "png or jpg, max. 20 MB" : "png of jpg, maks. 20 MB",
    "Choose as profile picture" : "Kies as profielprent",
    "Your phone number" : "U foonnommer",
    "Your postal address" : "U posadres",
    "Link https://…" : "Skakel https://…",
    "Twitter handle @…" : "Twitter-handvatsel @…",
    "Current password" : "Huidige wagwoord",
    "New password" : "Nuwe wagwoord",
    "Change password" : "Verander wagwoord",
    "Close" : "Sluit",
    "All languages" : "Alle tale",
    "Everyone" : "Almal",
    "days" : "dae",
    "For password reset and notifications" : "Vir wagwoordherstel en kennisgewings"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.2.10.tgz: nextcloud/apps/settings/l10n/af.js <==
OC.L10N.register(
    "settings",
    {
    "Private" : "Privaat",
    "Published" : "Gepubliseer",
    "Very weak password" : "Baie swak wagwoord",
    "Weak password" : "Swak wagwoord",
    "So-so password" : "Gemiddelde wagwoord",
    "Good password" : "Goeie wagwoord",
    "Strong password" : "Sterk wagwoord",
    "Groups" : "Groepe",
    "Group list is empty" : "Groeplys is leeg",
    "Unable to retrieve the group list" : "Kan nie die groeplys ophaal nie",
    "{actor} changed your password" : "{actor} het u wagwoord verander",
    "You changed your password" : "U het u wagwoord verander",
    "Your password was reset by an administrator" : "U wagwoord is deur ’n administrateur herstel",
    "{actor} changed your email address" : "{actor} het u e-posadres verander",
    "You changed your email address" : "U het u e-posadres verander",
    "Your email address was changed by an administrator" : "U e-posadres is deur ’n administrateur verander",
    "Security" : "Sekuriteit",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "U <strong>wagwoord</strong> of <strong>e-pos</strong> is gewysig",
    "Wrong password" : "Verkeerde wagwoord",
    "Saved" : "Bewaar",
    "No user supplied" : "Geen gebruiker verskaf nie",
    "Well done, %s!" : "Welgedaan %s!",
    "Invalid user" : "Ongeldige gebruiker",
    "Invalid mail address" : "Ongeldige posadres",
    "Settings saved" : "Instellings gestoor",
    "Go to %s" : "Gaan na %s",
    "Apps" : "Toeps",
    "Settings" : "Instellings",
    "Personal" : "Persoonlik",
    "Personal info" : "Persoonlike inligting",
    "Create" : "Skep",
    "Delete" : "Skrap",
    "Unlimited" : "Onbeperkte",
    "None" : "Geen",
    "Save changes" : "Bewaar veranderinge",
    "All" : "Alle",
    "Update to {version}" : "Werk by na {version}",
    "Remove" : "Verwyder",
    "Disable" : "Deaktiveer",
    "View in store" : "Bekyk in winkel",
    "Visit website" : "Besoek webwerf",
    "User documentation" : "Gebruikerdokumentasie",
    "Admin documentation" : "Admindokumentasie",
    "Developer documentation" : "Ontwikkelaardokumentasie",
    "Rename" : "Hernoem",
    "Device" : "Toestel",
    "App name" : "Toepnaam",
    "Create new app password" : "Skep nuwe toepwagwoord",
    "Username" : "Gebruikersnaam",
    "Password" : "Wagwoord",
    "Done" : "Gereed",
    "Copied!" : "Gekopieer!",
    "Copy" : "Kopieer",
    "Profile" : "Profiel",
    "Enable" : "Aktiveer",
    "Your email address" : "U e-posadres",
    "No email address set" : "Geen e-posadres ingestel",
    "Language" : "Taal",
    "Help translate" : "Help met vertaling",
    "Add" : "Voeg by",
    "Cancel" : "Kanselleer",
    "Display name" : "Vertoonnaam",
    "Email" : "E-pos",
    "Group admin for" : "Groepadmin vir",
    "Quota" : "Kwota",
    "Last login" : "Laaste aantekening",
    "Default quota" : "Verstekkwota",
    "Unnamed device" : "Onbenoemde toestel",
    "Your apps" : "U toeps",
    "Disabled apps" : "Gedeaktiveerde toeps",
    "Updates" : "Bywerkings",
    "App bundles" : "Toepbundels",
    "Details" : "Besonderhede",
    "Changelog" : "Veranderingslog",
    "Active users" : "Aktiewe gebruikers",
    "Send email to new user" : "Stuur e-pos aan nuwe gebruiker",
    "Email sent" : "E-pos gestuur",
    "Address" : "Adres",
    "About" : "Oor",
    "Full name" : "Volle naam",
    "Phone number" : "Foonnommer",
    "Twitter" : "Twitter",
    "Website" : "Webwerf",
    "Never" : "Nooit",
    "Administrator documentation" : "Administrateurdokumentasie",
    "Documentation" : "Dokumentasie",
    "Forum" : "Forum",
    "Login" : "Teken aan",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "Open dokumentasie",
    "Encryption" : "Enkripsie",
    "Authentication required" : "Verifikasie word vereis",
    "Server address" : "Bedieneradres",
    "Port" : "Poort",
    "SMTP Password" : "SMTP-wagwoord",
    "Save" : "Stoor",
    "Version" : "Weergawe",
    "Like our Facebook page" : "Hou van ons Facebook-blad",
    "Follow us on Twitter" : "Volg ons op Twitter",
    "Check out our blog" : "Besoek ons woernaal",
    "Subscribe to our newsletter" : "Teken in op ons nuusbrief",
    "Profile picture" : "Profielprent",
    "Upload new" : "Laai nuwe op",
    "Select from Files" : "Kies uit Lêers",
    "Remove image" : "Verwyder beeld",
    "png or jpg, max. 20 MB" : "png of jpg, maks. 20 MB",
    "Choose as profile picture" : "Kies as profielprent",
    "Your phone number" : "U foonnommer",
    "Your postal address" : "U posadres",
    "Link https://…" : "Skakel https://…",
    "Twitter handle @…" : "Twitter-handvatsel @…",
    "Current password" : "Huidige wagwoord",
    "New password" : "Nuwe wagwoord",
    "Change password" : "Verander wagwoord",
    "All languages" : "Alle tale",
    "Everyone" : "Almal",
    "days" : "dae"
},
"nplurals=2; plural=(n != 1);");
